@@ -6,10 +6,10 @@ https://www.aug.ipp.mpg.de/aug/manuals/aug_sfutils
 
 """
 __author__  = 'Giovanni Tardini (Tel. 1898)'
-__version__ = '0.7.9'
-__date__    = '23.05.2022'
+__version__ = '0.8.0'
+__date__    = '29.11.2022'
 
-import os, sys, logging
+import os, sys, logging, traceback
 
 fmt = logging.Formatter('%(asctime)s | %(name)s | %(levelname)s: %(message)s', '%H:%M:%S')
 
@@ -28,15 +28,13 @@ logger.info('Using version %s', __version__)
 try: # wrapper classes, available only with afs-client and kerberos access
     from .ww import *
 except:
+    traceback.print_exc()
     logger.warning('ww not loaded')
 try:
     from .sfh import *
 except:
+    traceback.print_exc()
     logger.warning('sfh not loaded')
-try:
-    from .journal import *
-except:
-    logger.warning('journal not loaded')
 
 from .sfread import *
 from .sf2equ import *
