@@ -12,7 +12,7 @@ logger = logging.getLogger('aug_sfutils.mapeq')
 
 def compare_version(a, b):
     from pkg_resources import parse_version
-    return parse_version(a) >= parse_version(b)
+    return parse_version(a) > parse_version(b)
 
 def get_nearest_index(tim_eq, tarr):
     """Find nearest time index for a given time.
@@ -24,7 +24,7 @@ def get_nearest_index(tim_eq, tarr):
         unique_idx = [0]
         index_idx = {0: [0]}
     else:
-        tarr = np.minimum(np.maximum(tarr, tim_eq[0]), tim_eq[-1])
+        tarr = np.clip(tarr, tim_eq[0], tim_eq[-1])
         idx = interp1d(tim_eq, np.arange(len(tim_eq)), kind='nearest', assume_sorted=True)(tarr)
         idx = idx.astype(np.int32)
         unique_idx = np.unique(idx)
@@ -124,7 +124,6 @@ def rho2rho(eqm, rho_in, t_in=None, \
     for i in unique_idx:
   
 # Calculate a normalized input and output flux 
-
         mag_out, sep_out = np.interp([PSI0[i], PSIX[i]],  PFL[i], label_out[i])
         if lbl_in != lbl_out:
             mag_in, sep_in = np.interp([PSI0[i], PSIX[i]],  PFL[i], label_in[i])
@@ -243,8 +242,8 @@ def rz2brzt(eqm, r_in, z_in, t_in=None):
 
     from scipy.constants import mu_0
     nr, nz = len(eqm.Rmesh), len(eqm.Zmesh)
-    dr = (eqm.Rmesh[-1] - eqm.Rmesh[0])/float(nr - 1)
-    dz = (eqm.Zmesh[-1] - eqm.Zmesh[0])/float(nz - 1)
+    dr = eqm.Rmesh[1] - eqm.Rmesh[0]
+    dz = eqm.Zmesh[1] - eqm.Zmesh[0]
 
     unique_idx, index_idx =  get_nearest_index(eqm.time, tarr)
 
@@ -252,21 +251,20 @@ def rz2brzt(eqm, r_in, z_in, t_in=None):
 
         jt = index_idx[i]
         Psi = eqm.pfm[:, :, i]
-        Br = np.apply_along_axis(np.gradient, 1,  Psi)/eqm.Rmesh[:, None]
-        Bz = np.apply_along_axis(np.gradient, 0, -Psi)/eqm.Rmesh[:, None]
+        Bpol = np.gradient(Psi, dr, dz)/eqm.Rmesh[:, None]
         fBt = interp1d(eqm.pfl[i], eqm.jpol[i], kind='linear', fill_value='extrapolate')
         Bt = fBt(Psi)*mu_0/eqm.Rmesh[:, None]
         r = r_in[jt] #np.squeeze(r_in[jt])
         z = z_in[jt] #np.squeeze(z_in[jt])
-        f_br = RectBivariateSpline(eqm.Rmesh, eqm.Zmesh, Br, kx=2, ky=2)
-        f_bz = RectBivariateSpline(eqm.Rmesh, eqm.Zmesh, Bz, kx=2, ky=2)
-        f_bt = RectBivariateSpline(eqm.Rmesh, eqm.Zmesh, Bt, kx=2, ky=2)
+        f_br = RectBivariateSpline(eqm.Rmesh, eqm.Zmesh,  Bpol[1], kx=2, ky=2)
+        f_bz = RectBivariateSpline(eqm.Rmesh, eqm.Zmesh, -Bpol[0], kx=2, ky=2)
+        f_bt = RectBivariateSpline(eqm.Rmesh, eqm.Zmesh,       Bt, kx=2, ky=2)
         interpBr[jt] = f_br(r, z, grid=False)
         interpBz[jt] = f_bz(r, z, grid=False)
         interpBt[jt] = f_bt(r, z, grid=False)
 
-    return interpBr/(-abs(eqm.psi_fac)*dz), \
-           interpBz/(-abs(eqm.psi_fac)*dr), \
+    return -interpBr/abs(eqm.psi_fac), \
+           -interpBz/abs(eqm.psi_fac), \
            interpBt/(2.*np.pi) * eqm.psi_sign * eqm.phi_sign
 
 
@@ -301,8 +299,8 @@ def Bmesh(eqm, t_in=None):
 
     nr = len(eqm.Rmesh)
     nz = len(eqm.Zmesh)
-    dr = (eqm.Rmesh[-1] - eqm.Rmesh[0])/float(nr - 1)
-    dz = (eqm.Zmesh[-1] - eqm.Zmesh[0])/float(nz - 1)
+    dr = eqm.Rmesh[1] - eqm.Rmesh[0]
+    dz = eqm.Zmesh[1] - eqm.Zmesh[0]
 
     unique_idx, index_idx =  get_nearest_index(eqm.time, tarr)
 
@@ -314,13 +312,14 @@ def Bmesh(eqm, t_in=None):
         jt = index_idx[i]
         Psi = eqm.pfm[:, :, i]
 # Eq 12 in Coco paper
-        Br[jt] = np.apply_along_axis(np.gradient, 1,  Psi)/eqm.Rmesh[:, None]
-        Bz[jt] = np.apply_along_axis(np.gradient, 0, -Psi)/eqm.Rmesh[:, None]
+        Bpol = np.gradient(Psi, dr, dz)/eqm.Rmesh[:, None]
+        Br[jt] =  Bpol[1]
+        Bz[jt] = -Bpol[0]
         fBt = interp1d(eqm.pfl[i], eqm.jpol[i], kind='linear', fill_value='extrapolate')
         Bt[jt] = fBt(Psi)*mu_0/eqm.Rmesh[:, None]
 
-    return Br/(-abs(eqm.psi_fac)*dz), \
-           Bz/(-abs(eqm.psi_fac)*dr), \
+    return -Br/abs(eqm.psi_fac), \
+           -Bz/abs(eqm.psi_fac), \
            Bt/(2.*np.pi) * eqm.psi_sign * eqm.phi_sign
 
 
@@ -855,7 +854,7 @@ def to_geqdsk(equ, t_in=0., cocos_out=1):
     today = datetime.datetime.today()
     date = today.strftime("%d%b%Y")
 
-    geq['CASE'] = np.array(['  CLISTE ', '    ', '   ', ' #' + str(equ.shot), '  %.2fs' % t_in, '  ' + 'EQI'], dtype='<U8')
+    geq['CASE'] = np.array(['  CLISTE ', '    ', '   ', ' #' + str(equ.shot), '  %.2fs' % t_in, '  ' + equ.diag], dtype='<U8')
 
     geq['CASE2'] = 'CLISTE %s  %s   %d    t~%10.5f     ' %(date, equ.diag, equ.shot, t_in)
     
