@@ -3,8 +3,10 @@
 import logging
 import numpy as np
 from scipy.integrate import cumtrapz
+from scipy.interpolate import interp1d
+from scipy.constants import mu_0
 
-from aug_sfutils import sfobj, SFREAD, parse_kwargs
+from aug_sfutils import sfobj, SFREAD, parse_kwargs, time_slice
 
 logger = logging.getLogger('aug_sfutils.sf2equ')
 
@@ -22,7 +24,7 @@ sigma = { \
 explain = {'rphiz'    : {1: '(R, phi, Z) r'    , -1: '(R, Z, phi) l'}, \
            'rhothephi': {1: '(rho, the, phi) r', -1: '(rho, phi, the) l'    } }
 
-
+ 
 class EQU:
     """Reads the whole equilibrium shotfile
     Reduces 1D profiles to within separatrix,
@@ -98,6 +100,19 @@ class EQU:
             logger.error('Problems opening %s:%s:%d for shot %d' %(exp, diag, ed, nshot))
             return
 
+        if 'tbeg' in kwargs.keys():
+            tbeg = kwargs['tbeg']
+        else:
+            tbeg = np.min(self.time)
+        if 'tend' in kwargs.keys():
+            tend = kwargs['tend']
+        else:
+            tend = np.max(self.time)
+
+        (self.indt, ) = np.where((self.time >= tbeg) & (self.time <= tend))
+        if len(self.indt) == 0:
+            self.indt = [np.argmin(np.abs(self.time - tbeg))]
+
         logger.info('Reading equ scalars')
         self.read_scalars()
         logger.info('Reading equ 1d profiles')
@@ -118,33 +133,22 @@ class EQU:
         self.psi_fac = self.psi_sign*psi_2pi
         self.phi_sign = self.bt_ccw*sigma['rphiz'][jcoco]
 
-        if 'tbeg' in kwargs.keys():
-            tbeg = kwargs['tbeg']
-        else:
-            tbeg = np.min(self.time)
-        if 'tend' in kwargs.keys():
-            tend = kwargs['tend']
-        else:
-            tend = np.max(self.time)
-
-        (indt, ) = np.where((self.time >= tbeg) & (self.time <= tend))
-        if len(indt) == 0:
-            indt = [np.argmin(np.abs(self.time - tbeg))]
-
-        self.time = self.time[indt]
+        self.time = self.time[self.indt]
         nt = len(self.time)
         nrho = np.max(self.lpfp) + 1
 
-        self.psi0 = self.psi0[indt]
-        self.psix = self.psix[indt]
+        self.psi0 = self.psi0[self.indt]
+        self.psix = self.psix[self.indt]
+        if hasattr(self, 'ipipsi'):
+            self.ipipsi = self.ipipsi[self.indt]
 
         for key in self.ssqnames:
-            self.__dict__[key] = self.__dict__[key][indt]
+            self.__dict__[key] = self.__dict__[key][self.indt]
         for key in ('pfl', 'tfl', 'ffp', 'rinv', 'q', \
              'area',  'vol',  'pres',  'jpol', \
             'darea', 'dvol', 'dpres', 'djpol') :
             if self.__dict__[key] is not None:
-                self.__dict__[key] = self.__dict__[key][indt, :nrho]
+                self.__dict__[key] = self.__dict__[key][self.indt, :nrho]
 
         ## Geometric major axis [m]
         self.R0 = 1.65
@@ -164,7 +168,14 @@ class EQU:
         ## Plasma current [A] as integral of current density
             self.ip = curr_prof[..., -1]
 
-        self.q[..., -1] = 2*self.q[..., -2] - self.q[..., -3]
+        self.q2 = np.zeros_like(self.q)
+        for jt in range(self.q.shape[0]):
+            self.q2[jt,  :] = self.q[jt, :]
+            self.q [jt, -1] = 2*self.q[jt, -2] - self.q[jt, -3]
+            self.q2[jt, -1] = 1.25*self.q[jt, -1]
+#            print(self.q2[jt, -1], self.q[jt, -1])
+
+
         ## Unnormalised rho toroidal
         self.rho_tor = np.sqrt(np.abs(self.tfl/(np.pi*self.B0[..., None])))
         ## Normalised rho toroidal
@@ -174,12 +185,12 @@ class EQU:
         self.tfln = np.zeros_like(self.tfl)
         for jt in range(nt):
             tf = self.tfl[jt]
-            torflux_trapz = cumtrapz(-self.q[jt], x=self.pfl[jt], initial=0.)
+            torflux_trapz = cumtrapz(-self.q2[jt], x=self.pfl[jt], initial=0.)
             self.tfln[jt, :] = tf/tf[-1]
             self.rho_tor_n[jt, 1:] = np.sqrt((tf[1:] - tf[0])/(tf[-1] - tf[0]))
             self.rhotor_trapz[jt, 1:] = np.sqrt( torflux_trapz[1:] / (torflux_trapz[-1] - torflux_trapz[0]) )
 
-        self.pfm = self.pfm[:, :, indt]
+        self.pfm = self.pfm[:, :, self.indt]
 
 
     def read_pfm(self):
@@ -243,7 +254,7 @@ class EQU:
 
         try:
             ## Plasma current[A]
-            self.ipipsi = self.sf.getobject('IpiPSI')[:nt]
+            self.ipipsi = self.sf.getobject('IpiPSI')[0]
         except:
             logger.exception('Signal IpiPSI not found')
 
@@ -364,6 +375,38 @@ class EQU:
         return var_sorted, dvar_sorted
 
 
+    def B_mesh(self):
+
+        """calculates Br, Bz, Bt profiles
+         """
+
+        nt = len(self.time)
+
+# Poloidal current 
+
+        nr = len(self.Rmesh)
+        nz = len(self.Zmesh)
+        dr = self.Rmesh[1] - self.Rmesh[0]
+        dz = self.Zmesh[1] - self.Zmesh[0]
+
+        self.Br = np.zeros((nt, nr, nz), dtype=np.float32)
+        self.Bz = np.zeros_like(self.Br)
+        self.Bt = np.zeros_like(self.Br)
+
+        for jt in range(nt):
+            Psi = self.pfm[:, :, jt]
+# Eq 12 in Coco paper
+            Bpol = np.gradient(Psi, dr, dz)/self.Rmesh[:, None]
+            self.Br[jt] =  Bpol[1]
+            self.Bz[jt] = -Bpol[0]
+            fBt = interp1d(self.pfl[jt], self.jpol[jt], kind='linear', fill_value='extrapolate')
+            self.Bt[jt] = fBt(Psi)*mu_0/self.Rmesh[:, None]
+
+        self.Br /= -abs(self.psi_fac)
+        self.Bz /= -abs(self.psi_fac)
+        self.Bt /=  2.*np.pi * self.psi_sign * self.phi_sign
+
+
     def find_coco(self, ip_shot='ccw', bt_shot='cw'):
         """
         Identifies the COCO number of a given equilibrium object
@@ -446,6 +489,28 @@ class EQU:
         self.cocos = cocos_out
 
 
+    def timeDownsample(self, time_ds, noELMs=False):
+
+        indbin  = None # Compute first time
+        ind_elm = None # Compute first time
+        self.noELMs = noELMs
+        nt = len(self.time)
+        self.pfm, self.ind_elm, self.indbin = time_slice.map2tgrid(time_ds, self.time, np.transpose(self.pfm, axes=(2, 0, 1)), nshot=self.shot, noELMs=self.noELMs)
+        self.pfm = np.transpose(self.pfm, axes=(1, 2, 0))
+
+        for attr, val in self.__dict__.items():
+            if attr in ('time', 'pfm'):
+                continue
+            if hasattr(val, 'shape'):
+                if val.dtype not in (np.float16, np.float32, np.float64, '>f4'):
+                    continue
+                if val.ndim > 0:
+                    if val.shape[0] == nt:
+                        tmp, _, _ = time_slice.map2tgrid(time_ds, self.time, getattr(self, attr), ind_elm=ind_elm, indbin=indbin)
+                        setattr(self, attr, tmp)
+
+        self.time = time_ds
+
 if __name__ == '__main__':
 
 
