@@ -5,9 +5,9 @@ import ctypes as ct
 import numpy as np
 from aug_sfutils import sfdics, str_byt, sfread
 
-sfhlib = '/afs/ipp/aug/ads/lib64/@sys/libsfh8.so.20201118'
+sfhlib = '/afs/ipp/aug/ads/lib64/@sys/libsfh8.so'
 if not os.path.isfile(sfhlib):
-    sfhlib = '/afs/ipp/aug/ads/lib64/amd64_sles11/libsfh8.so.20201118'
+    sfhlib = '/afs/ipp/aug/ads/lib64/amd64_sles11/libsfh8.so'
 
 libsfh = ct.cdll.LoadLibrary(sfhlib)
 
