@@ -1,4 +1,4 @@
-import logging
+import logging, traceback
 from struct import unpack, pack
 import numpy as np
 from aug_sfutils import sfdics, str_byt
@@ -25,16 +25,15 @@ def read_sfh(byt_str):
     n_obj = n_max
     for j in range(n_max):
         sfo = SFH_READ(byt_str[j*128: (j+1)*128])
-        if not hasattr(sfo, 'obj_type'):
-            continue
-        sfo.objid = j
-        onam = str_byt.to_str(sfo.objnam.strip())
-        if sfo.obj_type == Diagnostic:
-            if n_obj == n_max: # There might be several diags objects in a SFH
-                n_obj = sfo.num_objs
-        sfhead[onam] = sfo
-        obj_names.append(onam)
-        if j == n_obj - 1:
+        if hasattr(sfo, 'obj_type'):
+            sfo.objid = j
+            onam = str_byt.to_str(sfo.objnam.strip())
+            if sfo.obj_type == Diagnostic:
+                if n_obj == n_max: # There might be several diags objects in a SFH
+                    n_obj = sfo.num_objs
+            sfhead[onam] = sfo
+            obj_names.append(onam)
+        if j >= n_obj - 1:
             break
 
     for sfo in sfhead.values():
@@ -141,7 +140,11 @@ class SFH_READ:
         """
 
         self.data_format, self.physunit, self.num_dims = unpack('>3H' , self.val[: 6])
-        self.phys_unit = sfdics.unit_d[self.physunit]
+        if self.physunit in sfdics.unit_d.keys():
+            self.phys_unit = sfdics.unit_d[self.physunit]
+        else:
+            logger.warning('No phys. unit found for object %s, key=%d', self.objnam, self.physunit)
+            self.phys_unit = ''
         self.stat_ext = unpack('>h' , self.val[6: 8])[0]
         self.index    = list(unpack('>4I', self.val[8: 24]))
 
