@@ -42,9 +42,9 @@ def getError(error):
         ctrl = ct.byref(ct.c_uint32(3))
         libddww.xxerrprt_(unit, text, ct.byref(err), ctrl, id, ltext, lid);
         if isError:
-            raise Exception(text.value.strip())
+            raise Exception(text.value.decode().strip())
         else:
-            warnings.warn(text.value.strip(), RuntimeWarning)
+            warnings.warn(text.value.decode().strip(), RuntimeWarning)
 
 
 class WW:
